@@ -32,11 +32,14 @@ class Demo(object):
             resp.content_type='application/json'
             resp.body = simplejson.dumps([{'value':'Ajax'},{'value':'Borax'},{'value':'Corax'}, {'value':'Dorax'},{'value':'Manix'}])
         elif req.path.endswith('/fa.jquery/demo.html'):
+            req.remove_conditional_headers()
             script_name = req.environ.get('HTTP_X_FORWARDED_PATH', '')
             Form.ajax.set(renderer=AutoCompleteFieldRenderer(script_name+'/fa.jquery/ajax_values'))
             obj = Form.gen_model()
             obj.context['slider'] = '10'
             obj.context['sortable'] = '1;2;3'
+            obj.context['radioset'] = 'd'
+            obj.context['checkboxset'] = ['b', 'a']
             obj.context['selectable'] = 'f'
             obj.context['selectables'] = ['b', 'c']
             fs = Form.bind(obj, data=req.POST or None)
@@ -45,13 +48,14 @@ class Demo(object):
                         ('tab1', 'My first tab', fs1),
                         ('tab2', 'The second', fs2),
                         footer='<input type="submit" name="%(id)s" />')
-            tabs.bind(fs1.gen_model(), 'tab1', data=req.POST or None)
-            tabs.bind(fs2.gen_model(), 'tab2', data=req.POST or None)
+            tabs.tab1.rebind(fs1.gen_model(), data=req.POST or None)
+            tabs.tab2.rebind(fs2.gen_model(), data=req.POST or None)
             accordion = Accordion('my_accordion',
                         ('tab1', 'My first section', fs3),
                         ('tab2', 'The second', fs4),
                         footer='<input type="submit" name="%(id)s" />')
-            accordion.bind(fs3.gen_model(), data=req.POST or None)
+            accordion.tab1.rebind(fs3.gen_model(), data=req.POST or None)
+            accordion.tab2.rebind(fs4.gen_model(), data=req.POST or None)
             if req.POST:
                 if fs.validate():
                     fs.sync()
@@ -72,6 +76,7 @@ class Demo(object):
             else:
                 req.method = 'get'
                 resp = req.get_response(self.app)
+                resp.body = resp.body.replace('</head>', head+'</head>')
                 resp.body = resp.body.replace('<div id="demo"></div>', body)
         else:
             return self.app(environ, start_response)
